@@ -57,6 +57,10 @@ impl PlatformWindow {
         Err(PlatformError::NotImplemented)
     }
 
+    pub fn activate(&self) -> PlatformResult<bool> {
+        Err(PlatformError::NotImplemented)
+    }
+
     pub fn show_modal<F>(&self, done_callback: F)
     where
         F: FnOnce(PlatformResult<Value>) + 'static,
@@ -83,6 +87,14 @@ impl PlatformWindow {
         Err(PlatformError::NotImplemented)
     }
 
+    pub fn save_position_to_string(&self) -> PlatformResult<String> {
+        Ok(String::new())
+    }
+
+    pub fn restore_position_from_string(&self, position: String) -> PlatformResult<()> {
+        Ok(())
+    }
+
     pub fn set_style(&self, style: WindowStyle) -> PlatformResult<()> {
         Err(PlatformError::NotImplemented)
     }
