@@ -1,6 +1,4 @@
-use std::{ffi::CString, mem::size_of, ptr};
-
-use crate::shell::platform::key_interceptor::override_key_event;
+use std::{ffi::CString, ptr};
 
 use super::{
     binary_messenger::PlatformBinaryMessenger,
@@ -13,8 +11,10 @@ use super::{
     util::to_utf16,
 };
 
+pub type PlatformEngineType = FlutterDesktopEngineRef;
+
 pub struct PlatformEngine {
-    pub(super) handle: FlutterDesktopEngineRef,
+    pub(crate) handle: PlatformEngineType,
 }
 
 pub struct PlatformPlugin {
@@ -48,12 +48,6 @@ impl PlatformEngine {
                 }
             }
         }
-
-        unsafe {
-            // TODO: This makes assumption about internal engine layout and will possibly
-            // break in future;
-            override_key_event((engine as *mut u8).add(2 * size_of::<isize>()) as *mut _);
-        }
         Self { handle: engine }
     }
 
