@@ -7,6 +7,7 @@ pub enum PlatformError {
     SendMessageFailure { channel: String },
     WindowsError(windows::Error),
     NotAvailable,
+    OtherError { error: String },
 }
 
 pub type PlatformResult<T> = Result<T, PlatformError>;
@@ -27,6 +28,9 @@ impl Display for PlatformError {
             PlatformError::NotAvailable => {
                 write!(f, "Feature is not available")
             }
+            PlatformError::OtherError { error } => {
+                write!(f, "{}", error)
+            }
         }
     }
 }
