@@ -240,6 +240,10 @@ impl PlatformWindow {
         Ok(())
     }
 
+    pub fn activate(&self) -> PlatformResult<bool> {
+        self.state.borrow().activate()
+    }
+
     pub fn ready_to_show(&self) -> PlatformResult<()> {
         self.ready_to_show.set(true);
         if self.show_when_ready.get() {
@@ -288,6 +292,14 @@ impl PlatformWindow {
         self.state.borrow().set_title(title)
     }
 
+    pub fn save_position_to_string(&self) -> PlatformResult<String> {
+        self.state.borrow().save_position_to_string()
+    }
+
+    pub fn restore_position_from_string(&self, position: String) -> PlatformResult<()> {
+        self.state.borrow().restore_position_from_string(position)
+    }
+
     pub fn set_style(&self, style: WindowStyle) -> PlatformResult<()> {
         self.state.borrow().set_style(style)?;
         self.force_redraw();
